@@ -21,6 +21,7 @@ from sklearn.metrics import (
     r2_score,
     recall_score,
     roc_auc_score,
+    accuracy_score,
 )
 from sklearn.model_selection import train_test_split
 
@@ -219,6 +220,7 @@ class ModelResults:
             target variable (e.g. affected by 0.25)
         * Red/blue indicates feature value (increasing or decreasing feature has _ effect)
         * Blue & red mixed together indicate there isn't a clear effect on the target variable
+        * Interpreting magnitude number / x axis - changes the predicted probability of y on average by _ percentage points (axis value * 100)
 
         Parameters
         --------
@@ -459,10 +461,12 @@ class ModelResults:
         if model_type == "classification":
             pscore = precision_score(y_test, y_predicted)
             rscore = recall_score(y_test, y_predicted)
+            accuracy = accuracy_score(y_test, y_predicted)
             roc_auc = roc_auc_score(y_test, y_predicted)
 
             print(f"Final Model Precision: {pscore}")
             print(f"Final Model Recall: {rscore}")
+            print(f"Final Model Accuracy: {accuracy}")
             print(f"Final Model ROC AUC: {roc_auc}")
 
             crosstab = pd.crosstab(
